@@ -1,4 +1,4 @@
-#$Id: Agent.pm 17638 2012-08-30 03:52:17Z jensenma $
+#$Id: Agent.pm 17650 2012-08-31 03:41:43Z jensenma $
 package REST::Neo4p::Agent;
 use base LWP::UserAgent;
 use REST::Neo4p::Exceptions;
@@ -61,6 +61,12 @@ sub connect {
     next if /^extensions$/;
     $self->{_actions}{$_} = $json->{$_};
   }
+  # fix for incomplete discovery (relationship endpoint)
+  unless ($json->{relationship}) {
+    $self->{_actions}{relationship} = $self->{_actions}{node};
+    $self->{_actions}{relationship} =~ s/node/relationship/;
+  }
+
   return 1;
 }
 
@@ -95,7 +101,9 @@ sub AUTOLOAD {
 	%rest_params = %{ pop @url_components };
       }
       my $resp = $self->$rq(join('/',$self->{_actions}{$action}, @url_components),%rest_params);
-      $self->{_decoded_content} = $resp->content ? $JSON->decode($resp->content) : {};
+      eval { 
+	$self->{_decoded_content} = $resp->content ? $JSON->utf8->decode($resp->content) : {};
+      };
       unless ($resp->is_success) {
 	if ( $self->{_decoded_content} ) {
 	  REST::Neo4p::Neo4jException->throw( 
@@ -317,6 +325,10 @@ bareword was returned by the server.
 
 =head1 LICENSE
 
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
+can redistribute it and/or modify it under the same terms as Perl
+itself.
+
 =cut
 
 1;
